==> kipi-plugins-24.04.80.tar.xz: kipi-plugins-24.04.80/dropbox/kipiplugin_dropbox.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Dropbox Export
Name=Dropbox Export
Name[bg]=Изнасяне към Dropbox
Name[bs]=Dropbox Izvoz
Name[ca]=Exportador cap a Dropbox
Name[ca@valencia]=Exportador cap a Dropbox
Name[cs]=Export do Dropboxu
Name[da]=Eksport til Dropbox
Name[de]=Dropbox-Export
Name[el]=Εξαγωγή στο Dropbox
Name[en_GB]=Dropbox Export
Name[eo]=Dropbox-Eksporto
Name[es]=Exportar a Dropbox
Name[et]=Dropboxi eksport
Name[eu]=Dropbox-era esportatzea
Name[fi]=Dropbox-vienti
Name[fr]=Export vers Dropbox
Name[gl]=Exportación a Dropbox
Name[he]=ייצוא ל־Dropbox
Name[hu]=Dropbox exportálás
Name[ia]=Exporta a Dropbox
Name[id]=Dropbox Export
Name[is]=Dropbox útflutningur
Name[it]=Esportazione a Dropbox
Name[ka]=Dropbox-ზე გატანა
Name[ko]=Dropbox 내보내기
Name[nb]=Dropbox eksport
Name[nl]=Exporteren naar Dropbox
Name[nn]=Dropbox-eksport
Name[pl]=Wyeksportuj do Dropboksa
Name[pt]=Exportação para o Dropbox
Name[pt_BR]=Exportar para o Dropbox
Name[ro]=Export Dropbox
Name[ru]=Экспорт в Dropbox
Name[sk]=Dropbox Export
Name[sl]=Izvoz v Dropbox
Name[sv]=Export till Dropbox
Name[tr]=Dropbox'a Dışa Aktar
Name[uk]=Експорт до Dropbox
Name[x-test]=xxDropbox Exportxx
Name[zh_CN]=Dropbox 导出
Name[zh_TW]=Dropbox 匯出
Comment=A tool to export images to a remote Dropbox web service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Dropbox
Comment[bs]=Alat za izvoz slika na udaljeni Dropbox web servis
Comment[ca]=Una eina per a exportar les imatges al servei web remot de Dropbox
Comment[ca@valencia]=Una eina per a exportar les imatges cap al servei web remot de Dropbox
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Dropbox
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Dropbox-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Dropbox-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού του Dropbox
Comment[en_GB]=A tool to export images to a remote Dropbox web service
Comment[eo]=Ilo por eksporti bildojn al fora retservo de Dropbox
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Dropbox
Comment[et]=Tööriist piltide eksportimiseks Dropboxi veebiteenusesse
Comment[eu]=Irudiak urruneko Dropbox web zerbitzu batera esportatzeko tresna bat
Comment[fi]=Kuvien vienti Dropbox-verkkopalveluun
Comment[fr]=Un outil d'export d'images vers le service en ligne « Dropbox »
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Dropbox remoto
Comment[he]=כלי לייצוא תמונות לשירות Dropbox מרוחק
Comment[hu]=Egy eszköz képek exportálásához egy távoli Dropbox webszolgáltatásba
Comment[id]=Sebuah alat untuk mengekspor citra ke layanan web Dropbox jarak jauh
Comment[is]=Verkfæri til að senda myndir á fjartengda Dropbox vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio web remoto Dropbox
Comment[ka]=პროგრამა სურათების დაშორებულ Dropbox-ის ვებსერვისზე გასატანად
Comment[ko]=원격 Dropbox 웹 서비스로 사진을 내보내는 도구
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Dropbox-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Dropbox-webservice te exporteren
Comment[nn]=Verktøy for eksport av bilete til Dropbox-tenesta på nettet
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Dropboksa
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Dropbox
Comment[pt_BR]=Ferramenta para exportar imagens para o Dropbox
Comment[ro]=Unealtă de exportat imagini într-un serviciu web distant Dropbox
Comment[ru]=Инструмент для экспорта изображений в сетевое хранилище данных Dropbox
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Dropbox
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Dropbox
Comment[sv]=Ett verktyg för att exportera bilder till en Dropbox fjärrwebbtjänst
Comment[tr]=Görselleri uzak bir Dropbox web hizmetine dışa aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Dropbox
Comment[x-test]=xxA tool to export images to a remote Dropbox web servicexx
Comment[zh_CN]=一个将图像导出到远程 Dropbox 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Dropbox 網頁服務的工具
Type=Service
Icon=kipi-dropbox
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dropbox
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com

==> kipi-plugins-24.05.2.tar.xz: kipi-plugins-24.05.2/dropbox/kipiplugin_dropbox.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Dropbox Export
Name=Dropbox Export
Name[bg]=Изнасяне към Dropbox
Name[bs]=Dropbox Izvoz
Name[ca]=Exportador cap a Dropbox
Name[ca@valencia]=Exportador cap a Dropbox
Name[cs]=Export do Dropboxu
Name[da]=Eksport til Dropbox
Name[de]=Dropbox-Export
Name[el]=Εξαγωγή στο Dropbox
Name[en_GB]=Dropbox Export
Name[eo]=Dropbox-Eksporto
Name[es]=Exportar a Dropbox
Name[et]=Dropboxi eksport
Name[eu]=Dropbox-era esportatzea
Name[fi]=Dropbox-vienti
Name[fr]=Export vers DropBox
Name[gl]=Exportación a Dropbox
Name[he]=ייצוא ל־Dropbox
Name[hu]=Dropbox exportálás
Name[ia]=Exporta a Dropbox
Name[id]=Dropbox Export
Name[is]=Dropbox útflutningur
Name[it]=Esportazione a Dropbox
Name[ka]=Dropbox-ზე გატანა
Name[ko]=Dropbox 내보내기
Name[nb]=Dropbox eksport
Name[nl]=Exporteren naar Dropbox
Name[nn]=Dropbox-eksport
Name[pl]=Wyeksportuj do Dropboksa
Name[pt]=Exportação para o Dropbox
Name[pt_BR]=Exportar para o Dropbox
Name[ro]=Export Dropbox
Name[ru]=Экспорт в Dropbox
Name[sk]=Dropbox Export
Name[sl]=Izvoz v Dropbox
Name[sv]=Export till Dropbox
Name[tr]=Dropbox'a Dışa Aktar
Name[uk]=Експорт до Dropbox
Name[x-test]=xxDropbox Exportxx
Name[zh_CN]=Dropbox 导出
Name[zh_TW]=Dropbox 匯出
Comment=A tool to export images to a remote Dropbox web service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Dropbox
Comment[bs]=Alat za izvoz slika na udaljeni Dropbox web servis
Comment[ca]=Una eina per a exportar les imatges al servei web remot de Dropbox
Comment[ca@valencia]=Una eina per a exportar les imatges cap al servei web remot de Dropbox
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Dropbox
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Dropbox-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Dropbox-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού του Dropbox
Comment[en_GB]=A tool to export images to a remote Dropbox web service
Comment[eo]=Ilo por eksporti bildojn al fora retservo de Dropbox
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Dropbox
Comment[et]=Tööriist piltide eksportimiseks Dropboxi veebiteenusesse
Comment[eu]=Irudiak urruneko Dropbox web zerbitzu batera esportatzeko tresna bat
Comment[fi]=Kuvien vienti Dropbox-verkkopalveluun
Comment[fr]=Un outil d'export d'images vers le service en ligne « DropBox »
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Dropbox remoto
Comment[he]=כלי לייצוא תמונות לשירות Dropbox מרוחק
Comment[hu]=Egy eszköz képek exportálásához egy távoli Dropbox webszolgáltatásba
Comment[id]=Sebuah alat untuk mengekspor citra ke layanan web Dropbox jarak jauh
Comment[is]=Verkfæri til að senda myndir á fjartengda Dropbox vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio web remoto Dropbox
Comment[ka]=პროგრამა სურათების დაშორებულ Dropbox-ის ვებსერვისზე გასატანად
Comment[ko]=원격 Dropbox 웹 서비스로 사진을 내보내는 도구
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Dropbox-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Dropbox-webservice te exporteren
Comment[nn]=Verktøy for eksport av bilete til Dropbox-tenesta på nettet
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Dropboksa
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Dropbox
Comment[pt_BR]=Ferramenta para exportar imagens para o Dropbox
Comment[ro]=Unealtă de exportat imagini într-un serviciu web distant Dropbox
Comment[ru]=Инструмент для экспорта изображений в сетевое хранилище данных Dropbox
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Dropbox
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Dropbox
Comment[sv]=Ett verktyg för att exportera bilder till en Dropbox fjärrwebbtjänst
Comment[tr]=Görselleri uzak bir Dropbox web hizmetine dışa aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Dropbox
Comment[x-test]=xxA tool to export images to a remote Dropbox web servicexx
Comment[zh_CN]=一个将图像导出到远程 Dropbox 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Dropbox 網頁服務的工具
Type=Service
Icon=kipi-dropbox
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dropbox
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com
